# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AgeResolution,
    AnalysisConfig,
    AnalyzeConversationActionResult,
    AnalyzeConversationInput,
    AnalyzeConversationOperationResult,
    AnalyzeConversationOperationState,
    AnalyzeConversationResult,
    AnswerSpan,
    AnswersResult,
    AreaResolution,
    AudioTiming,
    BooleanResolution,
    ConversationActionContent,
    ConversationActionResult,
    ConversationActions,
    ConversationAnalysisInput,
    ConversationCallingConfig,
    ConversationConfig,
    ConversationEntity,
    ConversationEntityExtraInformation,
    ConversationError,
    ConversationInput,
    ConversationIntent,
    ConversationItemRange,
    ConversationLanguageUnderstandingInput,
    ConversationPiiItemResult,
    ConversationPiiOperationResult,
    ConversationPiiResults,
    ConversationPrediction,
    ConversationRequestStatistics,
    ConversationResult,
    ConversationStatistics,
    ConversationTargetIntentResult,
    ConversationalAIActionContent,
    ConversationalAIAnalysis,
    ConversationalAIAnalysisInput,
    ConversationalAIEntity,
    ConversationalAIIntent,
    ConversationalAIResult,
    ConversationalAITask,
    ConversationalAITaskResult,
    ConversationalPiiResult,
    ConversationsSummaryResult,
    CurrencyResolution,
    CustomSummarizationOperationResult,
    CustomSummaryResult,
    DateTimeResolution,
    DocumentError,
    EntitySubtype,
    EntityTag,
    ErrorResponse,
    InformationResolution,
    InnerErrorModel,
    InputWarning,
    ItemizedSummaryContext,
    KnowledgeBaseAnswer,
    KnowledgeBaseAnswerContext,
    KnowledgeBaseAnswerDialog,
    KnowledgeBaseAnswerPrompt,
    LengthResolution,
    ListKey,
    LuisCallingConfig,
    LuisConfig,
    LuisResult,
    LuisTargetIntentResult,
    MetadataFilter,
    MetadataRecord,
    NamedEntity,
    NonLinkedTargetIntentResult,
    NumberResolution,
    NumericRangeResolution,
    OrchestrationPrediction,
    OrdinalResolution,
    PredictionBase,
    QueryFilters,
    QuestionAnsweringConfig,
    QuestionAnsweringTargetIntentResult,
    QuestionAnswersConfig,
    RedactedTranscriptContent,
    RegexKey,
    RequestStatistics,
    ResolutionBase,
    ShortAnswerConfig,
    SpeedResolution,
    SummarizationOperationResult,
    SummaryResult,
    SummaryResultItem,
    TargetIntentResult,
    TemperatureResolution,
    TemporalSpanResolution,
    TextConversation,
    TextConversationItem,
    VolumeResolution,
    WeightResolution,
)

from ._enums import (  # type: ignore
    AgeUnit,
    AnalyzeConversationInputKind,
    AnalyzeConversationOperationResultsKind,
    AnalyzeConversationResultKind,
    AreaUnit,
    ConversationActionState,
    ConversationDomain,
    ConversationErrorCode,
    DateTimeSubKind,
    ExtraInformationKind,
    InformationUnit,
    InnerErrorCode,
    InputModality,
    LengthUnit,
    LogicalOperationKind,
    NumberKind,
    ParticipantRole,
    ProjectKind,
    RangeKind,
    RankerKind,
    RelativeTo,
    ResolutionKind,
    SpeedUnit,
    StringIndexType,
    SummaryAspect,
    SummaryLengthBucket,
    TargetProjectKind,
    TemperatureUnit,
    TemporalModifier,
    VolumeUnit,
    WeightUnit,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AgeResolution",
    "AnalysisConfig",
    "AnalyzeConversationActionResult",
    "AnalyzeConversationInput",
    "AnalyzeConversationOperationResult",
    "AnalyzeConversationOperationState",
    "AnalyzeConversationResult",
    "AnswerSpan",
    "AnswersResult",
    "AreaResolution",
    "AudioTiming",
    "BooleanResolution",
    "ConversationActionContent",
    "ConversationActionResult",
    "ConversationActions",
    "ConversationAnalysisInput",
    "ConversationCallingConfig",
    "ConversationConfig",
    "ConversationEntity",
    "ConversationEntityExtraInformation",
    "ConversationError",
    "ConversationInput",
    "ConversationIntent",
    "ConversationItemRange",
    "ConversationLanguageUnderstandingInput",
    "ConversationPiiItemResult",
    "ConversationPiiOperationResult",
    "ConversationPiiResults",
    "ConversationPrediction",
    "ConversationRequestStatistics",
    "ConversationResult",
    "ConversationStatistics",
    "ConversationTargetIntentResult",
    "ConversationalAIActionContent",
    "ConversationalAIAnalysis",
    "ConversationalAIAnalysisInput",
    "ConversationalAIEntity",
    "ConversationalAIIntent",
    "ConversationalAIResult",
    "ConversationalAITask",
    "ConversationalAITaskResult",
    "ConversationalPiiResult",
    "ConversationsSummaryResult",
    "CurrencyResolution",
    "CustomSummarizationOperationResult",
    "CustomSummaryResult",
    "DateTimeResolution",
    "DocumentError",
    "EntitySubtype",
    "EntityTag",
    "ErrorResponse",
    "InformationResolution",
    "InnerErrorModel",
    "InputWarning",
    "ItemizedSummaryContext",
    "KnowledgeBaseAnswer",
    "KnowledgeBaseAnswerContext",
    "KnowledgeBaseAnswerDialog",
    "KnowledgeBaseAnswerPrompt",
    "LengthResolution",
    "ListKey",
    "LuisCallingConfig",
    "LuisConfig",
    "LuisResult",
    "LuisTargetIntentResult",
    "MetadataFilter",
    "MetadataRecord",
    "NamedEntity",
    "NonLinkedTargetIntentResult",
    "NumberResolution",
    "NumericRangeResolution",
    "OrchestrationPrediction",
    "OrdinalResolution",
    "PredictionBase",
    "QueryFilters",
    "QuestionAnsweringConfig",
    "QuestionAnsweringTargetIntentResult",
    "QuestionAnswersConfig",
    "RedactedTranscriptContent",
    "RegexKey",
    "RequestStatistics",
    "ResolutionBase",
    "ShortAnswerConfig",
    "SpeedResolution",
    "SummarizationOperationResult",
    "SummaryResult",
    "SummaryResultItem",
    "TargetIntentResult",
    "TemperatureResolution",
    "TemporalSpanResolution",
    "TextConversation",
    "TextConversationItem",
    "VolumeResolution",
    "WeightResolution",
    "AgeUnit",
    "AnalyzeConversationInputKind",
    "AnalyzeConversationOperationResultsKind",
    "AnalyzeConversationResultKind",
    "AreaUnit",
    "ConversationActionState",
    "ConversationDomain",
    "ConversationErrorCode",
    "DateTimeSubKind",
    "ExtraInformationKind",
    "InformationUnit",
    "InnerErrorCode",
    "InputModality",
    "LengthUnit",
    "LogicalOperationKind",
    "NumberKind",
    "ParticipantRole",
    "ProjectKind",
    "RangeKind",
    "RankerKind",
    "RelativeTo",
    "ResolutionKind",
    "SpeedUnit",
    "StringIndexType",
    "SummaryAspect",
    "SummaryLengthBucket",
    "TargetProjectKind",
    "TemperatureUnit",
    "TemporalModifier",
    "VolumeUnit",
    "WeightUnit",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
